@@ -1,4 +1,5 @@
 import pytest
+from pygtrie import Trie as GTrie
 
 from sqltrie import SQLiteTrie
 
@@ -14,9 +15,10 @@ def items():
     return ret
 
 
-def test_set(benchmark, items):
+@pytest.mark.parametrize("cls", [SQLiteTrie, GTrie])
+def test_set(benchmark, items, cls):
     def _set():
-        trie = SQLiteTrie()
+        trie = cls()
 
         for subdir in ["foo", "bar", "baz"]:
             for idx in range(10000):
@@ -25,7 +27,8 @@ def test_set(benchmark, items):
     benchmark(_set)
 
 
-def test_items(benchmark, items):
+@pytest.mark.parametrize("cls", [SQLiteTrie, GTrie])
+def test_items(benchmark, items, cls):
     trie = SQLiteTrie()
 
     for subdir in ["foo", "bar", "baz"]:
@@ -36,3 +39,16 @@ def test_items(benchmark, items):
         list(trie.items())
 
     benchmark(_items)
+
+
+def test_diff(benchmark, items):
+    trie = SQLiteTrie()
+
+    for subdir in ["foo", "bar", "baz"]:
+        for idx in range(10000):
+            trie[(subdir, str(idx))] = bytes(idx)
+
+    def _diff():
+        list(trie.diff(None, None))
+
+    benchmark(_diff)
