@@ -32,9 +32,10 @@ def test_trie():
     with pytest.raises(KeyError):
         trie[("foo", "non-existent")]  # pylint: disable=pointless-statement
 
-    assert trie.longest_prefix(("non-existent",)) == ((), None)
-    assert trie.longest_prefix(("foo",)) == ((), None)
-    assert trie.longest_prefix(("foo", "non-existent")) == ((), None)
+    assert trie.longest_prefix(()) is None
+    assert trie.longest_prefix(("non-existent",)) is None
+    assert trie.longest_prefix(("foo",)) is None
+    assert trie.longest_prefix(("foo", "non-existent")) is None
     assert trie.longest_prefix(("foo", "bar", "baz", "qux")) == (
         ("foo", "bar", "baz"),
         b"baz-value",
